# Using R for Lab 3 Analysis Hue Naming
library(nlme)
par(ask=TRUE)

df <- read.delim("lab3_group_data.txt")
attach(df)
summary(df)

# Make a strip chart of the data
stripchart(zero_wavelength ~ color, method = "jitter", jitter = 0.03,
	ylab = "zero-crossing wavelength (nm)", 
	xlab = "Color", ylim = c(400, 650), vertical = TRUE)

# Make a box plot of the data:
boxplot(zero_wavelength ~ color, ylim = c(400, 650), data = df,
	ylab = "zero-crossing wavelength (nm)", 
	xlab = "Color", ylim = c(400, 650))

# plot the wavelengths for the pure colors from settings
# against the wavelengths derived from zero crossings
plot(pure_wavelength ~ zero_wavelength, data = df, type="n",
	xlim = c(400, 650),
	ylim = c(400, 650),
	xlab = "zero-crossing wavelengths",
	ylab = "pure-color wavelength",
	main = "Hue-Naming Laboratory")
abline(0,1)
points(pure_wavelength ~ zero_wavelength, data=subset(df,df$color=="blue"), col="blue", pch=19)
points(pure_wavelength ~ zero_wavelength, data=subset(df,df$color=="green"), col="green", pch=19)
points(pure_wavelength ~ zero_wavelength, data=subset(df,df$color=="yellow"), col="orange", pch=19)

# Testing the hypothesis that color is independent of wavelength and gender
# Compute the mixed-effects (within and between factors ANOVA
a <- lme(pure_wavelength ~ color * gender, random = ~ 1 | subj, data = df)

# print a summary of the analysis of variance
print(anova(a))

# Print a table of means:
print(tapply(df$pure_wavelength, df$color, mean, na.rm=TRUE))
print(tapply(df$zero_wavelength, df$color, mean, na.rm=TRUE))

# Print correlation between the two ways of measuring hue
print(cor(df$pure_wavelength, df$zero_wavelength))

par(ask=FALSE)